from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KNArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import KNArchives_pb2 as KNArchives__pb2
from . import TSDArchives_sos_pb2 as TSDArchives__sos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='KNArchives_sos.proto',
  package='KN',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x14KNArchives_sos.proto\x12\x02KN\x1a\x10KNArchives.proto\x1a\x15TSDArchives_sos.proto\"s\n\"SpecSetTransitionAttributesArchive\x12>\n\x15transition_attributes\x18\x01 \x01(\x0b\x32\x1f.KN.TransitionAttributesArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"q\n\x1fSpecTransitionAttributesArchive\x12N\n\x1espec_set_transition_attributes\x18\x01 \x01(\x0b\x32&.KN.SpecSetTransitionAttributesArchive\"\xc3\x01\n\"SlideStylePropertyChangeSetArchive\x12\"\n\x04\x66ill\x18\x01 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x16\n\x0e\x66ill_undefined\x18\x02 \x01(\x08\x12=\n\x10slide_transition\x18\x03 \x01(\x0b\x32#.KN.SpecTransitionAttributesArchive\x12\"\n\x1aslide_transition_undefined\x18\x04 \x01(\x08')
  ,
  dependencies=[KNArchives__pb2.DESCRIPTOR,TSDArchives__sos__pb2.DESCRIPTOR,])




_SPECSETTRANSITIONATTRIBUTESARCHIVE = _descriptor.Descriptor(
  name='SpecSetTransitionAttributesArchive',
  full_name='KN.SpecSetTransitionAttributesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transition_attributes', full_name='KN.SpecSetTransitionAttributesArchive.transition_attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='KN.SpecSetTransitionAttributesArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=184,
)


_SPECTRANSITIONATTRIBUTESARCHIVE = _descriptor.Descriptor(
  name='SpecTransitionAttributesArchive',
  full_name='KN.SpecTransitionAttributesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_transition_attributes', full_name='KN.SpecTransitionAttributesArchive.spec_set_transition_attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=299,
)


_SLIDESTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='SlideStylePropertyChangeSetArchive',
  full_name='KN.SlideStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='KN.SlideStylePropertyChangeSetArchive.fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_undefined', full_name='KN.SlideStylePropertyChangeSetArchive.fill_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_transition', full_name='KN.SlideStylePropertyChangeSetArchive.slide_transition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_transition_undefined', full_name='KN.SlideStylePropertyChangeSetArchive.slide_transition_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=497,
)

_SPECSETTRANSITIONATTRIBUTESARCHIVE.fields_by_name['transition_attributes'].message_type = KNArchives__pb2._TRANSITIONATTRIBUTESARCHIVE
_SPECTRANSITIONATTRIBUTESARCHIVE.fields_by_name['spec_set_transition_attributes'].message_type = _SPECSETTRANSITIONATTRIBUTESARCHIVE
_SLIDESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_SLIDESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['slide_transition'].message_type = _SPECTRANSITIONATTRIBUTESARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetTransitionAttributesArchive'] = _SPECSETTRANSITIONATTRIBUTESARCHIVE
DESCRIPTOR.message_types_by_name['SpecTransitionAttributesArchive'] = _SPECTRANSITIONATTRIBUTESARCHIVE
DESCRIPTOR.message_types_by_name['SlideStylePropertyChangeSetArchive'] = _SLIDESTYLEPROPERTYCHANGESETARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecSetTransitionAttributesArchive = _reflection.GeneratedProtocolMessageType('SpecSetTransitionAttributesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETTRANSITIONATTRIBUTESARCHIVE,
  __module__ = 'KNArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.SpecSetTransitionAttributesArchive)
  ))
_sym_db.RegisterMessage(SpecSetTransitionAttributesArchive)

SpecTransitionAttributesArchive = _reflection.GeneratedProtocolMessageType('SpecTransitionAttributesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECTRANSITIONATTRIBUTESARCHIVE,
  __module__ = 'KNArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.SpecTransitionAttributesArchive)
  ))
_sym_db.RegisterMessage(SpecTransitionAttributesArchive)

SlideStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('SlideStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDESTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'KNArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(SlideStylePropertyChangeSetArchive)


# @@protoc_insertion_point(module_scope)
